pub struct Portforwarder { /* private fields */ }Available on crate feature
client only.Expand description
Manages port-forwarded streams.
Provides AsyncRead + AsyncWrite for each port and does not bind to local ports. Error
channel for each port is only written by the server when there’s an exception and
the port cannot be used (didn’t initialize or can’t be used anymore).
Implementations
Sourceimpl Portforwarder
impl Portforwarder
Sourcepub fn take_stream(
&mut self,
port: u16,
) -> Option<impl AsyncRead + AsyncWrite + Unpin + use<>>
pub fn take_stream( &mut self, port: u16, ) -> Option<impl AsyncRead + AsyncWrite + Unpin + use<>>
Take a port stream by the port on the target resource.
A value is returned at most once per port.
Sourcepub fn take_error(
&mut self,
port: u16,
) -> Option<impl Future<Output = Option<String>> + use<>>
pub fn take_error( &mut self, port: u16, ) -> Option<impl Future<Output = Option<String>> + use<>>
Take a future that resolves with any error message or when the error sender is dropped. When the future resolves, the port should be considered no longer usable.
A value is returned at most once per port.