Resize

Trait Resize 

pub trait Resize { }
Available on crate features client and k8s_if_ge_1_33 only.
Marker trait for objects that support the resize sub resource.

The resize subresource allows updating container resource requests/limits without restarting the pod. This is available in Kubernetes 1.33+.

See Api::get_resize, Api::patch_resize, and Api::replace_resize.

See the Kubernetes documentation and limitations for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Resize for Pod

Implementors