ExecConfig

Struct ExecConfig 

pub struct ExecConfig {
    pub api_version: Option<String>,
    pub command: Option<String>,
    pub args: Option<Vec<String>>,
    pub env: Option<Vec<HashMap<String, String>>>,
    pub drop_env: Option<Vec<String>>,
    pub install_hint: Option<String>,
    pub interactive_mode: Option<ExecInteractiveMode>,
    pub provide_cluster_info: bool,
    pub cluster: Option<ExecAuthCluster>,
    pub other: BTreeMap<String, Value>,
}
Available on crate feature config only.
ExecConfig stores credential-plugin configuration.

Fields

api_version: Option<String>

Preferred input version of the ExecInfo.

The returned ExecCredentials MUST use the same encoding version as the input.

command: Option<String>

Command to execute.

args: Option<Vec<String>>

Arguments to pass to the command when executing it.

env: Option<Vec<HashMap<String, String>>>

Env defines additional environment variables to expose to the process.

TODO: These are unioned with the host’s environment, as well as variables client-go uses to pass argument to the plugin.

drop_env: Option<Vec<String>>

Specifies which environment variables the host should avoid passing to the auth plugin.

This does currently not exist upstream and cannot be specified on disk. It has been suggested in client-go via https://github.com/kubernetes/client-go/issues/1177

install_hint: Option<String>

This text is shown to the user when the executable doesn’t seem to be present. For example, brew install foo-cli might be a good InstallHint for foo-cli on Mac OS systems.

interactive_mode: Option<ExecInteractiveMode>

Interactive mode of the auth plugins

provide_cluster_info: bool

ProvideClusterInfo determines whether or not to provide cluster information, which could potentially contain very large CA data, to this exec plugin as a part of the KUBERNETES_EXEC_INFO environment variable. By default, it is set to false. Package k8s.io/client-go/tools/auth/exec provides helper methods for reading this environment variable.

cluster: Option<ExecAuthCluster>

Cluster information to pass to the plugin. Should be used only when provide_cluster_info is True.

other: BTreeMap<String, Value>

Additional fields not explicitly modeled, preserved for round-trip serialization.

If you are relying on this for standard fields present in upstream client-go, please consider submitting a PR to add them as typed fields.